# Vector - Python SDK

This is a fork of the original Anki Vector Python SDK. 
Since Anki is down and no longer supporting the SDK and the new owner [DDL](https://www.digitaldreamlabs.com/) is more likely working on firmware updates at the moment,
I just started this fork as an unofficial version to keep things running for now.  

![Vector](docs/source/images/vector-sdk-alpha.jpg)

Learn more about Vector: https://www.anki.com/en-us/vector

Learn more about how Vector works: [Vector Bible](https://github.com/GooeyChickenman/victor/blob/master/documentation/Vector-TRM.pdf)

SDK documentation: https://vector.ikkez.de/

Forums: https://forums.anki.com/

Discord: https://discord.gg/ue6v2Z


## Getting Started

You can follow steps [here](https://developer.anki.com/vector/docs/index.html) to set up your Vector robot with the SDK.

To install his SDK fork run:

```
pip uninstall anki_vector
pip install ikkez_vector
```

Upgrade with 
```
pip install ikkez_vector --upgrade
```

### Changelog

To see all changes and updates being made to the SDK, please go to [Releases](https://github.com/ikkez/vector-python-sdk/releases)

## Privacy Policy and Terms and Conditions

Use of Vector and the Vector SDK is subject to Anki's [Privacy Policy](https://www.anki.com/en-us/company/privacy) and [Terms and Conditions](https://www.anki.com/en-us/company/terms-and-conditions).
